@@ -40,7 +40,8 @@ from datetime import datetime
 from decimal import Decimal
 
 from hl7apy import get_default_encoding_chars, get_default_validation_level
-from hl7apy.exceptions import MaxLengthReached, InvalidHighlightRange, InvalidDateFormat, InvalidDateOffset
+from hl7apy.exceptions import MaxLengthReached, InvalidHighlightRange, InvalidDateFormat, \
+                              InvalidDateOffset, InvalidMicrosecondsPrecision
 from hl7apy.validation import Validator
 
 
@@ -234,20 +235,30 @@ class DT(DateTimeDataType):
 class TM(DateTimeDataType):
     """
     Class for TM base datatype. It extends DateTimeDatatype and it represents a time value with
-    hours, minutes, seconds and microseconds. Parameters are the same of the superclass plus ``offset``
+    hours, minutes, seconds and microseconds. Parameters are the same of the superclass plus ``offset``.
+    Since HL7 supports only four digits for microseconds, and Python datetime uses 6 digits, the wanted precision
+    must be specified.
 
     The :attr:`allowed_formats` tuple is ``('%H', '%H%M', '%H%M%S', '%H%M%S.%f')``.
     It needs also the ``offset`` parameter which represents the UTC offset
 
     :type offset: ``basestring``
     :param offset: the UTC offset. By default it is ''. It must be in the form ``'+/-HHMM'``
+
+    :type microsec_precision: ``int``
+    :param microsec_precision: Number of digit of the microseconds part of the value. It must be between 1 and 4
     """
 
     allowed_formats = ('%H', '%H%M', '%H%M%S', '%H%M%S.%f')
 
-    def __init__(self, value=None, format='%H%M%S.%f', offset=''):
+    def __init__(self, value=None, format='%H%M%S.%f', offset='', microsec_precision=4):
         super(TM, self).__init__(value, format)
 
+        if not (1 <= microsec_precision <= 4):
+            raise InvalidMicrosecondsPrecision()
+
+        self.microsec_precision = microsec_precision
+
         if offset and len(offset) != 5:
             raise InvalidDateOffset(offset)
         try:
@@ -264,12 +275,16 @@ class TM(DateTimeDataType):
         self.offset = offset
 
     def to_er7(self, encoding_chars=None):
-        return '{0}{1}'.format(super(TM, self).to_er7(), self.offset)
+        date_value = super(TM, self).to_er7()
+        if self.format.find('%f') != -1:
+            index = 6 - self.microsec_precision
+            date_value = date_value[:-index]
+        return '{0}{1}'.format(date_value, self.offset)
 
 
 class DTM(TM):
     """
-    Class for TM base datatype. It extends TM and it represents classes DT and DTM combined.
+    Class for DTM base datatype. It extends TM and it represents classes DT and DTM combined.
     Thus it represents year, month, day, hours, minutes, seconds and microseconds.
     Parameters are the same of the superclass.
 
@@ -280,8 +295,8 @@ class DTM(TM):
     allowed_formats = ('%Y', '%Y%m', '%Y%m%d', '%Y%m%d%H', '%Y%m%d%H%M',
                        '%Y%m%d%H%M%S', '%Y%m%d%H%M%S.%f')
 
-    def __init__(self, value=None, format='%Y%m%d%H%M%S.%f', offset=''):
-        super(DTM, self).__init__(value, format, offset)
+    def __init__(self, value=None, format='%Y%m%d%H%M%S.%f', offset='', microsec_precision=4):
+        super(DTM, self).__init__(value, format, offset, microsec_precision)
 
 
 class ST(TextualDataType):
