@@ -50,7 +50,7 @@ def get_base_datatypes():
     return BASE_DATATYPES
 
 def _load_base_datatypes():
-    base_datatypes = ('ST', 'ID', 'DT', 'DTM', 'FT', 'GTS', 'IS', 'NM', 'SI', 'TM', 'TX')
+    base_datatypes = ('ST', 'DT', 'FT', 'NM', 'TM', 'TX', 'TN', 'ID', 'SI')
     module = importlib.import_module("hl7apy.base_datatypes")
     datatypes = {}
     for cls in base_datatypes:
