@@ -47,6 +47,22 @@ SEGMENTS = {'ABS': ('sequence',
           ('ACC_10', (0, 1)),
           ('ACC_11', (0, 1)))),
  'ADD': ('sequence', (('ADD_1', (0, 1)),)),
+ 'ADJ': ('sequence',
+         (('ADJ_1', (1, 1)),
+          ('ADJ_2', (1, 1)),
+          ('ADJ_3', (1, 1)),
+          ('ADJ_4', (1, 1)),
+          ('ADJ_5', (0, 1)),
+          ('ADJ_6', (0, 1)),
+          ('ADJ_7', (0, -1)),
+          ('ADJ_8', (0, 1)),
+          ('ADJ_9', (0, 1)),
+          ('ADJ_10', (0, 1)),
+          ('ADJ_11', (0, 1)),
+          ('ADJ_12', (0, 1)),
+          ('ADJ_13', (0, 1)),
+          ('ADJ_14', (1, 1)),
+          ('ADJ_15', (0, 1)))),
  'AFF': ('sequence',
          (('AFF_1', (1, 1)),
           ('AFF_2', (1, 1)),
@@ -118,6 +134,7 @@ SEGMENTS = {'ABS': ('sequence',
                    (('ABS', (0, -1)),
                     ('ACC', (0, -1)),
                     ('ADD', (0, -1)),
+                    ('ADJ', (0, -1)),
                     ('AFF', (0, -1)),
                     ('AIG', (0, -1)),
                     ('AIL', (0, -1)),
@@ -126,6 +143,7 @@ SEGMENTS = {'ABS': ('sequence',
                     ('AL1', (0, -1)),
                     ('APR', (0, -1)),
                     ('ARQ', (0, -1)),
+                    ('ARV', (0, -1)),
                     ('AUT', (0, -1)),
                     ('BHS', (0, -1)),
                     ('BLC', (0, -1)),
@@ -148,16 +166,15 @@ SEGMENTS = {'ABS': ('sequence',
                     ('CTI', (0, -1)),
                     ('DB1', (0, -1)),
                     ('DG1', (0, -1)),
+                    ('DMI', (0, -1)),
                     ('DRG', (0, -1)),
                     ('DSC', (0, -1)),
                     ('DSP', (0, -1)),
                     ('ECD', (0, -1)),
                     ('ECR', (0, -1)),
                     ('EDU', (0, -1)),
-                    ('EQL', (0, -1)),
                     ('EQP', (0, -1)),
                     ('EQU', (0, -1)),
-                    ('ERQ', (0, -1)),
                     ('ERR', (0, -1)),
                     ('EVN', (0, -1)),
                     ('FAC', (0, -1)),
@@ -170,12 +187,17 @@ SEGMENTS = {'ABS': ('sequence',
                     ('GT1', (0, -1)),
                     ('IAM', (0, -1)),
                     ('IIM', (0, -1)),
+                    ('ILT', (0, -1)),
                     ('IN1', (0, -1)),
                     ('IN2', (0, -1)),
                     ('IN3', (0, -1)),
                     ('INV', (0, -1)),
                     ('IPC', (0, -1)),
+                    ('IPR', (0, -1)),
                     ('ISD', (0, -1)),
+                    ('ITM', (0, -1)),
+                    ('IVC', (0, -1)),
+                    ('IVT', (0, -1)),
                     ('LAN', (0, -1)),
                     ('LCC', (0, -1)),
                     ('LCH', (0, -1)),
@@ -209,6 +231,7 @@ SEGMENTS = {'ABS': ('sequence',
                     ('ORC', (0, -1)),
                     ('ORG', (0, -1)),
                     ('OVR', (0, -1)),
+                    ('PCE', (0, -1)),
                     ('PCR', (0, -1)),
                     ('PD1', (0, -1)),
                     ('PDA', (0, -1)),
@@ -216,15 +239,21 @@ SEGMENTS = {'ABS': ('sequence',
                     ('PEO', (0, -1)),
                     ('PES', (0, -1)),
                     ('PID', (0, -1)),
+                    ('PKG', (0, -1)),
+                    ('PMT', (0, -1)),
                     ('PR1', (0, -1)),
                     ('PRA', (0, -1)),
                     ('PRB', (0, -1)),
                     ('PRC', (0, -1)),
                     ('PRD', (0, -1)),
+                    ('PSG', (0, -1)),
                     ('PSH', (0, -1)),
+                    ('PSL', (0, -1)),
+                    ('PSS', (0, -1)),
                     ('PTH', (0, -1)),
                     ('PV1', (0, -1)),
                     ('PV2', (0, -1)),
+                    ('PYE', (0, -1)),
                     ('QAK', (0, -1)),
                     ('QID', (0, -1)),
                     ('QPD', (0, -1)),
@@ -234,7 +263,9 @@ SEGMENTS = {'ABS': ('sequence',
                     ('RCP', (0, -1)),
                     ('RDF', (0, -1)),
                     ('RDT', (0, -1)),
+                    ('REL', (0, -1)),
                     ('RF1', (0, -1)),
+                    ('RFI', (0, -1)),
                     ('RGS', (0, -1)),
                     ('RMI', (0, -1)),
                     ('ROL', (0, -1)),
@@ -248,23 +279,28 @@ SEGMENTS = {'ABS': ('sequence',
                     ('RXO', (0, -1)),
                     ('RXR', (0, -1)),
                     ('SAC', (0, -1)),
+                    ('SCD', (0, -1)),
                     ('SCH', (0, -1)),
+                    ('SCP', (0, -1)),
+                    ('SDD', (0, -1)),
                     ('SFT', (0, -1)),
                     ('SID', (0, -1)),
+                    ('SLT', (0, -1)),
                     ('SPM', (0, -1)),
-                    ('SPR', (0, -1)),
                     ('STF', (0, -1)),
+                    ('STZ', (0, -1)),
                     ('TCC', (0, -1)),
                     ('TCD', (0, -1)),
                     ('TQ1', (0, -1)),
                     ('TQ2', (0, -1)),
                     ('TXA', (0, -1)),
+                    ('UAC', (0, -1)),
                     ('UB1', (0, -1)),
                     ('UB2', (0, -1)),
                     ('URD', (0, -1)),
                     ('URS', (0, -1)),
                     ('VAR', (0, -1)),
-                    ('VTQ', (0, -1)))),
+                    ('VND', (0, -1)))),
  'APR': ('sequence',
          (('APR_1', (0, -1)),
           ('APR_2', (0, -1)),
@@ -297,6 +333,13 @@ SEGMENTS = {'ABS': ('sequence',
           ('ARQ_23', (0, 1)),
           ('ARQ_24', (0, -1)),
           ('ARQ_25', (0, -1)))),
+ 'ARV': ('sequence',
+         (('ARV_1', (0, 1)),
+          ('ARV_2', (1, 1)),
+          ('ARV_3', (1, 1)),
+          ('ARV_4', (0, -1)),
+          ('ARV_5', (0, -1)),
+          ('ARV_6', (0, 1)))),
  'AUT': ('sequence',
          (('AUT_1', (0, 1)),
           ('AUT_2', (1, 1)),
@@ -320,7 +363,9 @@ SEGMENTS = {'ABS': ('sequence',
           ('BHS_9', (0, 1)),
           ('BHS_10', (0, 1)),
           ('BHS_11', (0, 1)),
-          ('BHS_12', (0, 1)))),
+          ('BHS_12', (0, 1)),
+          ('BHS_13', (0, 1)),
+          ('BHS_14', (0, 1)))),
  'BLC': ('sequence', (('BLC_1', (0, 1)), ('BLC_2', (0, 1)))),
  'BLG': ('sequence',
          (('BLG_1', (0, 1)),
@@ -435,7 +480,7 @@ SEGMENTS = {'ABS': ('sequence',
  'CM0': ('sequence',
          (('CM0_1', (0, 1)),
           ('CM0_2', (1, 1)),
-          ('CM0_3', (0, -1)),
+          ('CM0_3', (0, 3)),
           ('CM0_4', (1, 1)),
           ('CM0_5', (0, -1)),
           ('CM0_6', (0, 1)),
@@ -450,7 +495,7 @@ SEGMENTS = {'ABS': ('sequence',
          (('CM2_1', (0, 1)),
           ('CM2_2', (1, 1)),
           ('CM2_3', (0, 1)),
-          ('CM2_4', (1, -1)))),
+          ('CM2_4', (1, 200)))),
  'CNS': ('sequence',
          (('CNS_1', (0, 1)),
           ('CNS_2', (0, 1)),
@@ -500,14 +545,14 @@ SEGMENTS = {'ABS': ('sequence',
           ('CSR_8', (1, -1)),
           ('CSR_9', (0, 1)),
           ('CSR_10', (0, 1)),
-          ('CSR_11', (0, -1)),
-          ('CSR_12', (0, -1)),
-          ('CSR_13', (0, -1)),
+          ('CSR_11', (0, 3)),
+          ('CSR_12', (0, 3)),
+          ('CSR_13', (0, 3)),
           ('CSR_14', (0, 1)),
           ('CSR_15', (0, 1)),
           ('CSR_16', (0, 1)))),
  'CSS': ('sequence',
-         (('CSS_1', (1, 1)), ('CSS_2', (0, 1)), ('CSS_3', (0, -1)))),
+         (('CSS_1', (1, 1)), ('CSS_2', (0, 1)), ('CSS_3', (0, 3)))),
  'CTD': ('sequence',
          (('CTD_1', (1, -1)),
           ('CTD_2', (0, -1)),
@@ -529,26 +574,27 @@ SEGMENTS = {'ABS': ('sequence',
           ('DB1_8', (0, 1)))),
  'DG1': ('sequence',
          (('DG1_1', (1, 1)),
-          ('DG1_2', (0, 1)),
-          ('DG1_3', (0, 1)),
-          ('DG1_4', (0, 1)),
+          ('DG1_3', (1, 1)),
           ('DG1_5', (0, 1)),
           ('DG1_6', (1, 1)),
-          ('DG1_7', (0, 1)),
-          ('DG1_8', (0, 1)),
-          ('DG1_9', (0, 1)),
-          ('DG1_10', (0, 1)),
-          ('DG1_11', (0, 1)),
-          ('DG1_12', (0, 1)),
-          ('DG1_13', (0, 1)),
-          ('DG1_14', (0, 1)),
           ('DG1_15', (0, 1)),
           ('DG1_16', (0, -1)),
           ('DG1_17', (0, 1)),
           ('DG1_18', (0, 1)),
           ('DG1_19', (0, 1)),
           ('DG1_20', (0, 1)),
-          ('DG1_21', (0, 1)))),
+          ('DG1_21', (0, 1)),
+          ('DG1_22', (0, 1)),
+          ('DG1_23', (0, 1)),
+          ('DG1_24', (0, 1)),
+          ('DG1_25', (0, 1)),
+          ('DG1_26', (0, 1)))),
+ 'DMI': ('sequence',
+         (('DMI_1', (0, 1)),
+          ('DMI_2', (0, 1)),
+          ('DMI_3', (0, 1)),
+          ('DMI_4', (0, 1)),
+          ('DMI_5', (0, 1)))),
  'DRG': ('sequence',
          (('DRG_1', (0, 1)),
           ('DRG_2', (0, 1)),
@@ -560,7 +606,29 @@ SEGMENTS = {'ABS': ('sequence',
           ('DRG_8', (0, 1)),
           ('DRG_9', (0, 1)),
           ('DRG_10', (0, 1)),
-          ('DRG_11', (0, 1)))),
+          ('DRG_11', (0, 1)),
+          ('DRG_12', (0, 1)),
+          ('DRG_13', (0, 1)),
+          ('DRG_14', (0, 1)),
+          ('DRG_15', (0, 1)),
+          ('DRG_16', (0, 1)),
+          ('DRG_17', (0, 1)),
+          ('DRG_18', (0, 1)),
+          ('DRG_19', (0, 1)),
+          ('DRG_20', (0, 1)),
+          ('DRG_21', (0, 1)),
+          ('DRG_22', (0, 1)),
+          ('DRG_23', (0, 1)),
+          ('DRG_24', (0, 1)),
+          ('DRG_25', (0, 1)),
+          ('DRG_26', (0, 1)),
+          ('DRG_27', (0, 1)),
+          ('DRG_28', (0, 1)),
+          ('DRG_29', (0, 1)),
+          ('DRG_30', (0, 1)),
+          ('DRG_31', (0, 1)),
+          ('DRG_32', (0, 1)),
+          ('DRG_33', (0, 1)))),
  'DSC': ('sequence', (('DSC_1', (0, 1)), ('DSC_2', (0, 1)))),
  'DSP': ('sequence',
          (('DSP_1', (0, 1)),
@@ -586,11 +654,6 @@ SEGMENTS = {'ABS': ('sequence',
           ('EDU_7', (0, 1)),
           ('EDU_8', (0, 1)),
           ('EDU_9', (0, -1)))),
- 'EQL': ('sequence',
-         (('EQL_1', (0, 1)),
-          ('EQL_2', (1, 1)),
-          ('EQL_3', (1, 1)),
-          ('EQL_4', (1, 1)))),
  'EQP': ('sequence',
          (('EQP_1', (1, 1)),
           ('EQP_2', (0, 1)),
@@ -603,15 +666,13 @@ SEGMENTS = {'ABS': ('sequence',
           ('EQU_3', (0, 1)),
           ('EQU_4', (0, 1)),
           ('EQU_5', (0, 1)))),
- 'ERQ': ('sequence',
-         (('ERQ_1', (0, 1)), ('ERQ_2', (1, 1)), ('ERQ_3', (0, -1)))),
  'ERR': ('sequence',
          (('ERR_1', (0, -1)),
           ('ERR_2', (0, -1)),
           ('ERR_3', (1, 1)),
           ('ERR_4', (1, 1)),
           ('ERR_5', (0, 1)),
-          ('ERR_6', (0, -1)),
+          ('ERR_6', (0, 10)),
           ('ERR_7', (0, 1)),
           ('ERR_8', (0, 1)),
           ('ERR_9', (0, -1)),
@@ -651,7 +712,9 @@ SEGMENTS = {'ABS': ('sequence',
           ('FHS_9', (0, 1)),
           ('FHS_10', (0, 1)),
           ('FHS_11', (0, 1)),
-          ('FHS_12', (0, 1)))),
+          ('FHS_12', (0, 1)),
+          ('FHS_13', (0, 1)),
+          ('FHS_14', (0, 1)))),
  'FT1': ('sequence',
          (('FT1_1', (0, 1)),
           ('FT1_2', (0, 1)),
@@ -660,8 +723,6 @@ SEGMENTS = {'ABS': ('sequence',
           ('FT1_5', (0, 1)),
           ('FT1_6', (1, 1)),
           ('FT1_7', (1, 1)),
-          ('FT1_8', (0, 1)),
-          ('FT1_9', (0, 1)),
           ('FT1_10', (0, 1)),
           ('FT1_11', (0, 1)),
           ('FT1_12', (0, 1)),
@@ -706,7 +767,8 @@ SEGMENTS = {'ABS': ('sequence',
           ('GOL_18', (0, 1)),
           ('GOL_19', (0, 1)),
           ('GOL_20', (0, -1)),
-          ('GOL_21', (0, -1)))),
+          ('GOL_21', (0, -1)),
+          ('GOL_22', (0, 1)))),
  'GP1': ('sequence',
          (('GP1_1', (1, 1)),
           ('GP1_2', (0, -1)),
@@ -823,6 +885,17 @@ SEGMENTS = {'ABS': ('sequence',
           ('IIM_13', (0, 1)),
           ('IIM_14', (0, 1)),
           ('IIM_15', (0, -1)))),
+ 'ILT': ('sequence',
+         (('ILT_1', (1, 1)),
+          ('ILT_2', (1, 1)),
+          ('ILT_3', (0, 1)),
+          ('ILT_4', (0, 1)),
+          ('ILT_5', (0, 1)),
+          ('ILT_6', (0, 1)),
+          ('ILT_7', (0, 1)),
+          ('ILT_8', (0, 1)),
+          ('ILT_9', (0, 1)),
+          ('ILT_10', (0, 1)))),
  'IN1': ('sequence',
          (('IN1_1', (1, 1)),
           ('IN1_2', (1, 1)),
@@ -861,10 +934,7 @@ SEGMENTS = {'ABS': ('sequence',
           ('IN1_35', (0, 1)),
           ('IN1_36', (0, 1)),
           ('IN1_37', (0, 1)),
-          ('IN1_38', (0, 1)),
           ('IN1_39', (0, 1)),
-          ('IN1_40', (0, 1)),
-          ('IN1_41', (0, 1)),
           ('IN1_42', (0, 1)),
           ('IN1_43', (0, 1)),
           ('IN1_44', (0, -1)),
@@ -935,7 +1005,7 @@ SEGMENTS = {'ABS': ('sequence',
           ('IN2_55', (0, 1)),
           ('IN2_56', (0, -1)),
           ('IN2_57', (0, 1)),
-          ('IN2_58', (0, 1)),
+          ('IN2_58', (0, -1)),
           ('IN2_59', (0, 1)),
           ('IN2_60', (0, 1)),
           ('IN2_61', (0, 1)),
@@ -1007,8 +1077,105 @@ SEGMENTS = {'ABS': ('sequence',
           ('IPC_7', (0, 1)),
           ('IPC_8', (0, -1)),
           ('IPC_9', (0, 1)))),
+ 'IPR': ('sequence',
+         (('IPR_1', (1, 1)),
+          ('IPR_2', (1, 1)),
+          ('IPR_3', (1, 1)),
+          ('IPR_4', (1, 1)),
+          ('IPR_5', (1, 1)),
+          ('IPR_6', (0, 1)),
+          ('IPR_7', (0, 1)),
+          ('IPR_8', (1, 1)))),
  'ISD': ('sequence',
          (('ISD_1', (1, 1)), ('ISD_2', (0, 1)), ('ISD_3', (1, 1)))),
+ 'ITM': ('sequence',
+         (('ITM_1', (1, 1)),
+          ('ITM_2', (0, 1)),
+          ('ITM_3', (0, 1)),
+          ('ITM_4', (0, 1)),
+          ('ITM_5', (0, 1)),
+          ('ITM_6', (0, 1)),
+          ('ITM_7', (0, 1)),
+          ('ITM_8', (0, 1)),
+          ('ITM_9', (0, 1)),
+          ('ITM_10', (0, 1)),
+          ('ITM_11', (0, 1)),
+          ('ITM_12', (0, 1)),
+          ('ITM_13', (0, 1)),
+          ('ITM_14', (0, 1)),
+          ('ITM_15', (0, 1)),
+          ('ITM_16', (0, -1)),
+          ('ITM_17', (0, 1)),
+          ('ITM_18', (0, -1)),
+          ('ITM_19', (0, 1)),
+          ('ITM_20', (0, 1)),
+          ('ITM_21', (0, 1)),
+          ('ITM_22', (0, 1)),
+          ('ITM_23', (0, 1)),
+          ('ITM_24', (0, 1)),
+          ('ITM_25', (0, 1)),
+          ('ITM_26', (0, 1)),
+          ('ITM_27', (0, 1)),
+          ('ITM_28', (0, -1)),
+          ('ITM_29', (0, 1)))),
+ 'IVC': ('sequence',
+         (('IVC_1', (1, 1)),
+          ('IVC_2', (0, 1)),
+          ('IVC_3', (0, 1)),
+          ('IVC_4', (1, 1)),
+          ('IVC_5', (1, 1)),
+          ('IVC_6', (1, 1)),
+          ('IVC_7', (1, 1)),
+          ('IVC_8', (1, 1)),
+          ('IVC_9', (0, 1)),
+          ('IVC_10', (1, 1)),
+          ('IVC_11', (1, 1)),
+          ('IVC_12', (0, 1)),
+          ('IVC_13', (0, 1)),
+          ('IVC_14', (0, 1)),
+          ('IVC_15', (0, 1)),
+          ('IVC_16', (0, 1)),
+          ('IVC_17', (0, 1)),
+          ('IVC_18', (0, 1)),
+          ('IVC_19', (0, 1)),
+          ('IVC_20', (0, 1)),
+          ('IVC_21', (0, 1)),
+          ('IVC_22', (0, 1)),
+          ('IVC_23', (0, 1)),
+          ('IVC_24', (0, -1)),
+          ('IVC_25', (1, 1)),
+          ('IVC_26', (0, 1)),
+          ('IVC_27', (0, 1)),
+          ('IVC_28', (0, 1)),
+          ('IVC_29', (0, 1)),
+          ('IVC_30', (0, 1)))),
+ 'IVT': ('sequence',
+         (('IVT_1', (1, 1)),
+          ('IVT_2', (1, 1)),
+          ('IVT_3', (0, 1)),
+          ('IVT_4', (0, 1)),
+          ('IVT_5', (0, 1)),
+          ('IVT_6', (0, 1)),
+          ('IVT_7', (0, -1)),
+          ('IVT_8', (0, 1)),
+          ('IVT_9', (0, 1)),
+          ('IVT_10', (0, 1)),
+          ('IVT_11', (0, 1)),
+          ('IVT_12', (0, 1)),
+          ('IVT_13', (0, 1)),
+          ('IVT_14', (0, 1)),
+          ('IVT_15', (0, 1)),
+          ('IVT_16', (0, 1)),
+          ('IVT_17', (0, 1)),
+          ('IVT_18', (0, 1)),
+          ('IVT_19', (0, -1)),
+          ('IVT_20', (0, 1)),
+          ('IVT_21', (0, 1)),
+          ('IVT_22', (0, 1)),
+          ('IVT_23', (0, 1)),
+          ('IVT_24', (0, 1)),
+          ('IVT_25', (0, 1)),
+          ('IVT_26', (0, 1)))),
  'LAN': ('sequence',
          (('LAN_1', (1, 1)),
           ('LAN_2', (1, 1)),
@@ -1067,10 +1234,12 @@ SEGMENTS = {'ABS': ('sequence',
           ('MFE_2', (0, 1)),
           ('MFE_3', (0, 1)),
           ('MFE_4', (1, -1)),
-          ('MFE_5', (1, -1)))),
+          ('MFE_5', (1, -1)),
+          ('MFE_6', (0, 1)),
+          ('MFE_7', (0, 1)))),
  'MFI': ('sequence',
          (('MFI_1', (1, 1)),
-          ('MFI_2', (0, 1)),
+          ('MFI_2', (0, -1)),
           ('MFI_3', (1, 1)),
           ('MFI_4', (0, 1)),
           ('MFI_5', (0, 1)),
@@ -1088,7 +1257,9 @@ SEGMENTS = {'ABS': ('sequence',
           ('MSA_2', (1, 1)),
           ('MSA_3', (0, 1)),
           ('MSA_4', (0, 1)),
-          ('MSA_6', (0, 1)))),
+          ('MSA_6', (0, 1)),
+          ('MSA_7', (0, 1)),
+          ('MSA_8', (0, 1)))),
  'MSH': ('sequence',
          (('MSH_1', (1, 1)),
           ('MSH_2', (1, 1)),
@@ -1110,7 +1281,11 @@ SEGMENTS = {'ABS': ('sequence',
           ('MSH_18', (0, -1)),
           ('MSH_19', (0, 1)),
           ('MSH_20', (0, 1)),
-          ('MSH_21', (0, -1)))),
+          ('MSH_21', (0, -1)),
+          ('MSH_22', (0, 1)),
+          ('MSH_23', (0, 1)),
+          ('MSH_24', (0, 1)),
+          ('MSH_25', (0, 1)))),
  'NCK': ('sequence', (('NCK_1', (1, 1)),)),
  'NDS': ('sequence',
          (('NDS_1', (1, 1)),
@@ -1188,7 +1363,11 @@ SEGMENTS = {'ABS': ('sequence',
          (('NTE_1', (0, 1)),
           ('NTE_2', (0, 1)),
           ('NTE_3', (0, -1)),
-          ('NTE_4', (0, 1)))),
+          ('NTE_4', (0, 1)),
+          ('NTE_5', (0, 1)),
+          ('NTE_6', (0, 1)),
+          ('NTE_7', (0, 1)),
+          ('NTE_8', (0, 1)))),
  'OBR': ('sequence',
          (('OBR_1', (0, 1)),
           ('OBR_2', (0, 1)),
@@ -1206,7 +1385,7 @@ SEGMENTS = {'ABS': ('sequence',
           ('OBR_14', (0, 1)),
           ('OBR_15', (0, 1)),
           ('OBR_16', (0, -1)),
-          ('OBR_17', (0, -1)),
+          ('OBR_17', (0, 2)),
           ('OBR_18', (0, 1)),
           ('OBR_19', (0, 1)),
           ('OBR_20', (0, 1)),
@@ -1260,16 +1439,19 @@ SEGMENTS = {'ABS': ('sequence',
           ('OBX_17', (0, -1)),
           ('OBX_18', (0, -1)),
           ('OBX_19', (0, 1)),
-          ('OBX_20', (0, 1)),
+          ('OBX_20', (0, -1)),
           ('OBX_21', (0, 1)),
-          ('OBX_22', (0, 1)))),
+          ('OBX_22', (0, 1)),
+          ('OBX_23', (0, -1)),
+          ('OBX_24', (0, -1)),
+          ('OBX_25', (0, -1)))),
  'ODS': ('sequence',
          (('ODS_1', (1, 1)),
-          ('ODS_2', (0, -1)),
-          ('ODS_3', (1, -1)),
-          ('ODS_4', (0, -1)))),
+          ('ODS_2', (0, 10)),
+          ('ODS_3', (1, 20)),
+          ('ODS_4', (0, 2)))),
  'ODT': ('sequence',
-         (('ODT_1', (1, 1)), ('ODT_2', (0, -1)), ('ODT_3', (0, 1)))),
+         (('ODT_1', (1, 1)), ('ODT_2', (0, 10)), ('ODT_3', (0, 1)))),
  'OM1': ('sequence',
          (('OM1_1', (1, 1)),
           ('OM1_2', (1, 1)),
@@ -1332,7 +1514,7 @@ SEGMENTS = {'ABS': ('sequence',
  'OM3': ('sequence',
          (('OM3_1', (0, 1)),
           ('OM3_2', (0, 1)),
-          ('OM3_3', (0, 1)),
+          ('OM3_3', (0, -1)),
           ('OM3_4', (0, -1)),
           ('OM3_5', (0, -1)),
           ('OM3_6', (0, -1)),
@@ -1394,7 +1576,7 @@ SEGMENTS = {'ABS': ('sequence',
           ('ORC_11', (0, -1)),
           ('ORC_12', (0, -1)),
           ('ORC_13', (0, 1)),
-          ('ORC_14', (0, -1)),
+          ('ORC_14', (0, 2)),
           ('ORC_15', (0, 1)),
           ('ORC_16', (0, 1)),
           ('ORC_17', (0, 1)),
@@ -1431,6 +1613,11 @@ SEGMENTS = {'ABS': ('sequence',
           ('OVR_3', (0, 1)),
           ('OVR_4', (0, 1)),
           ('OVR_5', (0, 1)))),
+ 'PCE': ('sequence',
+         (('PCE_1', (1, 1)),
+          ('PCE_2', (0, 1)),
+          ('PCE_3', (0, 1)),
+          ('PCE_4', (0, 1)))),
  'PCR': ('sequence',
          (('PCR_1', (1, 1)),
           ('PCR_2', (0, 1)),
@@ -1443,7 +1630,7 @@ SEGMENTS = {'ABS': ('sequence',
           ('PCR_9', (0, 1)),
           ('PCR_10', (0, 1)),
           ('PCR_11', (0, 1)),
-          ('PCR_12', (0, -1)),
+          ('PCR_12', (0, 3)),
           ('PCR_13', (0, 1)),
           ('PCR_14', (0, 1)),
           ('PCR_15', (0, 1)),
@@ -1452,9 +1639,9 @@ SEGMENTS = {'ABS': ('sequence',
           ('PCR_18', (0, 1)),
           ('PCR_19', (0, 1)),
           ('PCR_20', (0, 1)),
-          ('PCR_21', (0, -1)),
-          ('PCR_22', (0, -1)),
-          ('PCR_23', (0, -1)))),
+          ('PCR_21', (0, 6)),
+          ('PCR_22', (0, 6)),
+          ('PCR_23', (0, 3)))),
  'PD1': ('sequence',
          (('PD1_1', (0, -1)),
           ('PD1_2', (0, 1)),
@@ -1476,7 +1663,8 @@ SEGMENTS = {'ABS': ('sequence',
           ('PD1_18', (0, 1)),
           ('PD1_19', (0, 1)),
           ('PD1_20', (0, 1)),
-          ('PD1_21', (0, 1)))),
+          ('PD1_21', (0, 1)),
+          ('PD1_22', (0, 1)))),
  'PDA': ('sequence',
          (('PDA_1', (0, -1)),
           ('PDA_2', (0, 1)),
@@ -1540,7 +1728,7 @@ SEGMENTS = {'ABS': ('sequence',
           ('PES_8', (0, 1)),
           ('PES_9', (0, 1)),
           ('PES_10', (1, 1)),
-          ('PES_11', (0, -1)),
+          ('PES_11', (0, 2)),
           ('PES_12', (0, 1)),
           ('PES_13', (0, -1)))),
  'PID': ('sequence',
@@ -1581,21 +1769,37 @@ SEGMENTS = {'ABS': ('sequence',
           ('PID_35', (0, 1)),
           ('PID_36', (0, 1)),
           ('PID_37', (0, 1)),
-          ('PID_38', (0, 1)),
+          ('PID_38', (0, -1)),
           ('PID_39', (0, -1)))),
+ 'PKG': ('sequence',
+         (('PKG_1', (1, 1)),
+          ('PKG_2', (0, 1)),
+          ('PKG_3', (0, 1)),
+          ('PKG_4', (0, 1)),
+          ('PKG_5', (0, 1)),
+          ('PKG_6', (0, 1)),
+          ('PKG_7', (0, 1)))),
+ 'PMT': ('sequence',
+         (('PMT_1', (1, 1)),
+          ('PMT_2', (1, 1)),
+          ('PMT_3', (1, 1)),
+          ('PMT_4', (1, 1)),
+          ('PMT_5', (1, 1)),
+          ('PMT_6', (1, 1)),
+          ('PMT_7', (0, 1)),
+          ('PMT_8', (0, 1)),
+          ('PMT_9', (0, 1)),
+          ('PMT_10', (0, 1)),
+          ('PMT_11', (1, 1)),
+          ('PMT_12', (0, 1)))),
  'PR1': ('sequence',
          (('PR1_1', (1, 1)),
-          ('PR1_2', (0, 1)),
           ('PR1_3', (1, 1)),
-          ('PR1_4', (0, 1)),
           ('PR1_5', (1, 1)),
           ('PR1_6', (0, 1)),
           ('PR1_7', (0, 1)),
-          ('PR1_8', (0, -1)),
           ('PR1_9', (0, 1)),
           ('PR1_10', (0, 1)),
-          ('PR1_11', (0, -1)),
-          ('PR1_12', (0, -1)),
           ('PR1_13', (0, 1)),
           ('PR1_14', (0, 1)),
           ('PR1_15', (0, 1)),
@@ -1603,7 +1807,9 @@ SEGMENTS = {'ABS': ('sequence',
           ('PR1_17', (0, 1)),
           ('PR1_18', (0, -1)),
           ('PR1_19', (0, 1)),
-          ('PR1_20', (0, 1)))),
+          ('PR1_20', (0, 1)),
+          ('PR1_21', (0, 1)),
+          ('PR1_22', (0, 1)))),
  'PRA': ('sequence',
          (('PRA_1', (0, 1)),
           ('PRA_2', (0, -1)),
@@ -1642,7 +1848,10 @@ SEGMENTS = {'ABS': ('sequence',
           ('PRB_22', (0, 1)),
           ('PRB_23', (0, 1)),
           ('PRB_24', (0, 1)),
-          ('PRB_25', (0, 1)))),
+          ('PRB_25', (0, 1)),
+          ('PRB_26', (0, 1)),
+          ('PRB_27', (0, 1)),
+          ('PRB_28', (0, 1)))),
  'PRC': ('sequence',
          (('PRC_1', (1, 1)),
           ('PRC_2', (0, -1)),
@@ -1671,7 +1880,19 @@ SEGMENTS = {'ABS': ('sequence',
           ('PRD_6', (0, 1)),
           ('PRD_7', (0, -1)),
           ('PRD_8', (0, 1)),
-          ('PRD_9', (0, 1)))),
+          ('PRD_9', (0, -1)),
+          ('PRD_10', (0, -1)),
+          ('PRD_11', (0, -1)),
+          ('PRD_12', (0, -1)),
+          ('PRD_13', (0, -1)),
+          ('PRD_14', (0, -1)))),
+ 'PSG': ('sequence',
+         (('PSG_1', (1, 1)),
+          ('PSG_2', (0, 1)),
+          ('PSG_3', (1, 1)),
+          ('PSG_4', (1, 1)),
+          ('PSG_5', (1, 1)),
+          ('PSG_6', (1, 1)))),
  'PSH': ('sequence',
          (('PSH_1', (1, 1)),
           ('PSH_2', (0, 1)),
@@ -1685,15 +1906,71 @@ SEGMENTS = {'ABS': ('sequence',
           ('PSH_10', (0, 1)),
           ('PSH_11', (0, 1)),
           ('PSH_12', (0, 1)),
-          ('PSH_13', (0, -1)),
-          ('PSH_14', (0, -1)))),
+          ('PSH_13', (0, 8)),
+          ('PSH_14', (0, 8)))),
+ 'PSL': ('sequence',
+         (('PSL_1', (1, 1)),
+          ('PSL_2', (0, 1)),
+          ('PSL_3', (1, 1)),
+          ('PSL_4', (0, 1)),
+          ('PSL_5', (0, 1)),
+          ('PSL_6', (1, 1)),
+          ('PSL_7', (1, 1)),
+          ('PSL_8', (0, -1)),
+          ('PSL_9', (0, 1)),
+          ('PSL_10', (0, 1)),
+          ('PSL_11', (0, 1)),
+          ('PSL_12', (0, 1)),
+          ('PSL_13', (0, 1)),
+          ('PSL_14', (0, 1)),
+          ('PSL_15', (0, 1)),
+          ('PSL_16', (0, 1)),
+          ('PSL_17', (0, -1)),
+          ('PSL_18', (0, -1)),
+          ('PSL_19', (0, -1)),
+          ('PSL_20', (0, -1)),
+          ('PSL_21', (1, 1)),
+          ('PSL_22', (0, 1)),
+          ('PSL_23', (0, 1)),
+          ('PSL_24', (0, 1)),
+          ('PSL_25', (0, 1)),
+          ('PSL_26', (0, 1)),
+          ('PSL_27', (0, 1)),
+          ('PSL_28', (0, 1)),
+          ('PSL_29', (0, 1)),
+          ('PSL_30', (0, 1)),
+          ('PSL_31', (0, 1)),
+          ('PSL_32', (0, 1)),
+          ('PSL_33', (0, 1)),
+          ('PSL_34', (0, 1)),
+          ('PSL_35', (0, 1)),
+          ('PSL_36', (0, 1)),
+          ('PSL_37', (0, 1)),
+          ('PSL_38', (0, 1)),
+          ('PSL_39', (0, 1)),
+          ('PSL_40', (0, 1)),
+          ('PSL_41', (0, 1)),
+          ('PSL_42', (0, 1)),
+          ('PSL_43', (0, 1)),
+          ('PSL_44', (0, 1)),
+          ('PSL_45', (0, 1)),
+          ('PSL_46', (0, 1)),
+          ('PSL_47', (0, 1)),
+          ('PSL_48', (0, 1)))),
+ 'PSS': ('sequence',
+         (('PSS_1', (1, 1)),
+          ('PSS_2', (0, 1)),
+          ('PSS_3', (1, 1)),
+          ('PSS_4', (1, 1)),
+          ('PSS_5', (1, 1)))),
  'PTH': ('sequence',
          (('PTH_1', (1, 1)),
           ('PTH_2', (1, 1)),
           ('PTH_3', (1, 1)),
           ('PTH_4', (1, 1)),
           ('PTH_5', (0, 1)),
-          ('PTH_6', (0, 1)))),
+          ('PTH_6', (0, 1)),
+          ('PTH_7', (0, 1)))),
  'PV1': ('sequence',
          (('PV1_1', (0, 1)),
           ('PV1_2', (1, 1)),
@@ -1739,7 +2016,7 @@ SEGMENTS = {'ABS': ('sequence',
           ('PV1_42', (0, 1)),
           ('PV1_43', (0, 1)),
           ('PV1_44', (0, 1)),
-          ('PV1_45', (0, -1)),
+          ('PV1_45', (0, 1)),
           ('PV1_46', (0, 1)),
           ('PV1_47', (0, 1)),
           ('PV1_48', (0, 1)),
@@ -1796,7 +2073,16 @@ SEGMENTS = {'ABS': ('sequence',
           ('PV2_46', (0, 1)),
           ('PV2_47', (0, 1)),
           ('PV2_48', (0, 1)),
-          ('PV2_49', (0, -1)))),
+          ('PV2_49', (0, -1)),
+          ('PV2_50', (0, 1)))),
+ 'PYE': ('sequence',
+         (('PYE_1', (1, 1)),
+          ('PYE_2', (1, 1)),
+          ('PYE_3', (0, 1)),
+          ('PYE_4', (0, -1)),
+          ('PYE_5', (0, -1)),
+          ('PYE_6', (0, -1)),
+          ('PYE_7', (0, 1)))),
  'QAK': ('sequence',
          (('QAK_1', (0, 1)),
           ('QAK_2', (0, 1)),
@@ -1843,6 +2129,23 @@ SEGMENTS = {'ABS': ('sequence',
           ('RCP_7', (0, -1)))),
  'RDF': ('sequence', (('RDF_1', (1, 1)), ('RDF_2', (1, -1)))),
  'RDT': ('sequence', (('RDT_1', (1, 1)),)),
+ 'REL': ('sequence',
+         (('REL_1', (0, 1)),
+          ('REL_2', (1, 1)),
+          ('REL_3', (1, 1)),
+          ('REL_4', (1, 1)),
+          ('REL_5', (1, 1)),
+          ('REL_6', (0, 1)),
+          ('REL_7', (0, 1)),
+          ('REL_8', (0, 1)),
+          ('REL_9', (0, 1)),
+          ('REL_10', (0, 1)),
+          ('REL_11', (0, 1)),
+          ('REL_12', (0, 1)),
+          ('REL_13', (0, 1)),
+          ('REL_14', (0, 1)),
+          ('REL_15', (0, 1)),
+          ('REL_16', (0, 1)))),
  'RF1': ('sequence',
          (('RF1_1', (0, 1)),
           ('RF1_2', (0, 1)),
@@ -1854,7 +2157,13 @@ SEGMENTS = {'ABS': ('sequence',
           ('RF1_8', (0, 1)),
           ('RF1_9', (0, 1)),
           ('RF1_10', (0, -1)),
-          ('RF1_11', (0, -1)))),
+          ('RF1_11', (0, -1)),
+          ('RF1_12', (0, 1)))),
+ 'RFI': ('sequence',
+         (('RFI_1', (1, 1)),
+          ('RFI_2', (1, 1)),
+          ('RFI_3', (0, 1)),
+          ('RFI_4', (0, 1)))),
  'RGS': ('sequence',
          (('RGS_1', (1, 1)), ('RGS_2', (0, 1)), ('RGS_3', (0, 1)))),
  'RMI': ('sequence',
@@ -1871,7 +2180,8 @@ SEGMENTS = {'ABS': ('sequence',
           ('ROL_9', (0, -1)),
           ('ROL_10', (0, 1)),
           ('ROL_11', (0, -1)),
-          ('ROL_12', (0, -1)))),
+          ('ROL_12', (0, -1)),
+          ('ROL_13', (0, 1)))),
  'RQ1': ('sequence',
          (('RQ1_1', (0, 1)),
           ('RQ1_2', (0, 1)),
@@ -1917,7 +2227,9 @@ SEGMENTS = {'ABS': ('sequence',
           ('RXA_23', (0, 1)),
           ('RXA_24', (0, 1)),
           ('RXA_25', (0, 1)),
-          ('RXA_26', (0, 1)))),
+          ('RXA_26', (0, 1)),
+          ('RXA_27', (0, 1)),
+          ('RXA_28', (0, 1)))),
  'RXC': ('sequence',
          (('RXC_1', (1, 1)),
           ('RXC_2', (1, 1)),
@@ -2033,7 +2345,11 @@ SEGMENTS = {'ABS': ('sequence',
           ('RXG_23', (0, 1)),
           ('RXG_24', (0, 1)),
           ('RXG_25', (0, 1)),
-          ('RXG_26', (0, 1)))),
+          ('RXG_26', (0, 1)),
+          ('RXG_27', (0, 1)),
+          ('RXG_28', (0, 1)),
+          ('RXG_29', (0, 1)),
+          ('RXG_30', (0, 1)))),
  'RXO': ('sequence',
          (('RXO_1', (0, 1)),
           ('RXO_2', (0, 1)),
@@ -2062,7 +2378,14 @@ SEGMENTS = {'ABS': ('sequence',
           ('RXO_25', (0, 1)),
           ('RXO_26', (0, 1)),
           ('RXO_27', (0, 1)),
-          ('RXO_28', (0, 1)))),
+          ('RXO_28', (0, 1)),
+          ('RXO_29', (0, 1)),
+          ('RXO_30', (0, 1)),
+          ('RXO_31', (0, 1)),
+          ('RXO_32', (0, 1)),
+          ('RXO_33', (0, 1)),
+          ('RXO_34', (0, 1)),
+          ('RXO_35', (0, 1)))),
  'RXR': ('sequence',
          (('RXR_1', (1, 1)),
           ('RXR_2', (0, 1)),
@@ -2115,6 +2438,44 @@ SEGMENTS = {'ABS': ('sequence',
           ('SAC_42', (0, 1)),
           ('SAC_43', (0, -1)),
           ('SAC_44', (0, -1)))),
+ 'SCD': ('sequence',
+         (('SCD_1', (0, 1)),
+          ('SCD_2', (0, 1)),
+          ('SCD_3', (0, 1)),
+          ('SCD_4', (0, 1)),
+          ('SCD_5', (0, 1)),
+          ('SCD_6', (0, 1)),
+          ('SCD_7', (0, 1)),
+          ('SCD_8', (0, 1)),
+          ('SCD_9', (0, 1)),
+          ('SCD_10', (0, 1)),
+          ('SCD_11', (0, 1)),
+          ('SCD_12', (0, 1)),
+          ('SCD_13', (0, 1)),
+          ('SCD_14', (0, 1)),
+          ('SCD_15', (0, 1)),
+          ('SCD_16', (0, 1)),
+          ('SCD_17', (0, 1)),
+          ('SCD_18', (0, 1)),
+          ('SCD_19', (0, 1)),
+          ('SCD_20', (0, 1)),
+          ('SCD_21', (0, 1)),
+          ('SCD_22', (0, 1)),
+          ('SCD_23', (0, 1)),
+          ('SCD_24', (0, 1)),
+          ('SCD_25', (0, 1)),
+          ('SCD_26', (0, 1)),
+          ('SCD_27', (0, 1)),
+          ('SCD_28', (0, 1)),
+          ('SCD_29', (0, 1)),
+          ('SCD_30', (0, 1)),
+          ('SCD_31', (0, 1)),
+          ('SCD_32', (0, 1)),
+          ('SCD_33', (0, -1)),
+          ('SCD_34', (0, 1)),
+          ('SCD_35', (0, 1)),
+          ('SCD_36', (0, 1)),
+          ('SCD_37', (0, 1)))),
  'SCH': ('sequence',
          (('SCH_1', (0, 1)),
           ('SCH_2', (0, 1)),
@@ -2143,6 +2504,23 @@ SEGMENTS = {'ABS': ('sequence',
           ('SCH_25', (0, 1)),
           ('SCH_26', (0, -1)),
           ('SCH_27', (0, -1)))),
+ 'SCP': ('sequence',
+         (('SCP_1', (0, 1)),
+          ('SCP_2', (0, 1)),
+          ('SCP_3', (0, 1)),
+          ('SCP_4', (0, 1)),
+          ('SCP_5', (0, 1)),
+          ('SCP_6', (0, 1)),
+          ('SCP_7', (0, 1)),
+          ('SCP_8', (0, 1)))),
+ 'SDD': ('sequence',
+         (('SDD_1', (0, 1)),
+          ('SDD_2', (0, 1)),
+          ('SDD_3', (0, 1)),
+          ('SDD_4', (0, 1)),
+          ('SDD_5', (0, 1)),
+          ('SDD_6', (0, 1)),
+          ('SDD_7', (0, 1)))),
  'SFT': ('sequence',
          (('SFT_1', (1, 1)),
           ('SFT_2', (1, 1)),
@@ -2155,6 +2533,12 @@ SEGMENTS = {'ABS': ('sequence',
           ('SID_2', (0, 1)),
           ('SID_3', (0, 1)),
           ('SID_4', (0, 1)))),
+ 'SLT': ('sequence',
+         (('SLT_1', (0, 1)),
+          ('SLT_2', (0, 1)),
+          ('SLT_3', (0, 1)),
+          ('SLT_4', (0, 1)),
+          ('SLT_5', (0, 1)))),
  'SPM': ('sequence',
          (('SPM_1', (0, 1)),
           ('SPM_2', (0, 1)),
@@ -2185,11 +2569,6 @@ SEGMENTS = {'ABS': ('sequence',
           ('SPM_27', (0, 1)),
           ('SPM_28', (0, 1)),
           ('SPM_29', (0, 1)))),
- 'SPR': ('sequence',
-         (('SPR_1', (0, 1)),
-          ('SPR_2', (1, 1)),
-          ('SPR_3', (1, 1)),
-          ('SPR_4', (0, -1)))),
  'STF': ('sequence',
          (('STF_1', (0, 1)),
           ('STF_2', (0, -1)),
@@ -2228,7 +2607,13 @@ SEGMENTS = {'ABS': ('sequence',
           ('STF_35', (0, 1)),
           ('STF_36', (0, -1)),
           ('STF_37', (0, 1)),
-          ('STF_38', (0, 1)))),
+          ('STF_38', (0, 1)),
+          ('STF_39', (0, -1)))),
+ 'STZ': ('sequence',
+         (('STZ_1', (0, 1)),
+          ('STZ_2', (0, 1)),
+          ('STZ_3', (0, 1)),
+          ('STZ_4', (0, 1)))),
  'TCC': ('sequence',
          (('TCC_1', (1, 1)),
           ('TCC_2', (1, 1)),
@@ -2303,23 +2688,23 @@ SEGMENTS = {'ABS': ('sequence',
           ('TXA_21', (0, 1)),
           ('TXA_22', (0, -1)),
           ('TXA_23', (0, -1)))),
+ 'UAC': ('sequence', (('UAC_1', (1, 1)), ('UAC_2', (1, 1)))),
  'UB1': ('sequence',
          (('UB1_1', (0, 1)),
-          ('UB1_2', (0, 1)),
           ('UB1_3', (0, 1)),
           ('UB1_4', (0, 1)),
           ('UB1_5', (0, 1)),
           ('UB1_6', (0, 1)),
-          ('UB1_7', (0, -1)),
+          ('UB1_7', (0, 5)),
           ('UB1_8', (0, 1)),
           ('UB1_9', (0, 1)),
-          ('UB1_10', (0, -1)),
+          ('UB1_10', (0, 8)),
           ('UB1_11', (0, 1)),
           ('UB1_12', (0, 1)),
           ('UB1_13', (0, 1)),
           ('UB1_14', (0, 1)),
           ('UB1_15', (0, 1)),
-          ('UB1_16', (0, -1)),
+          ('UB1_16', (0, 5)),
           ('UB1_17', (0, 1)),
           ('UB1_18', (0, 1)),
           ('UB1_19', (0, 1)),
@@ -2330,20 +2715,20 @@ SEGMENTS = {'ABS': ('sequence',
  'UB2': ('sequence',
          (('UB2_1', (0, 1)),
           ('UB2_2', (0, 1)),
-          ('UB2_3', (0, -1)),
+          ('UB2_3', (0, 7)),
           ('UB2_4', (0, 1)),
           ('UB2_5', (0, 1)),
-          ('UB2_6', (0, -1)),
-          ('UB2_7', (0, -1)),
-          ('UB2_8', (0, -1)),
-          ('UB2_9', (0, -1)),
-          ('UB2_10', (0, -1)),
+          ('UB2_6', (0, 12)),
+          ('UB2_7', (0, 8)),
+          ('UB2_8', (0, 2)),
+          ('UB2_9', (0, 2)),
+          ('UB2_10', (0, 2)),
           ('UB2_11', (0, 1)),
-          ('UB2_12', (0, -1)),
-          ('UB2_13', (0, -1)),
-          ('UB2_14', (0, -1)),
+          ('UB2_12', (0, 3)),
+          ('UB2_13', (0, 23)),
+          ('UB2_14', (0, 5)),
           ('UB2_15', (0, 1)),
-          ('UB2_16', (0, -1)),
+          ('UB2_16', (0, 2)),
           ('UB2_17', (0, 1)))),
  'URD': ('sequence',
          (('URD_1', (0, 1)),
@@ -2370,9 +2755,9 @@ SEGMENTS = {'ABS': ('sequence',
           ('VAR_4', (0, -1)),
           ('VAR_5', (0, 1)),
           ('VAR_6', (0, -1)))),
- 'VTQ': ('sequence',
-         (('VTQ_1', (0, 1)),
-          ('VTQ_2', (1, 1)),
-          ('VTQ_3', (1, 1)),
-          ('VTQ_4', (1, 1)),
-          ('VTQ_5', (0, -1))))}
+ 'VND': ('sequence',
+         (('VND_1', (1, 1)),
+          ('VND_2', (1, 1)),
+          ('VND_3', (0, 1)),
+          ('VND_4', (0, 1)),
+          ('VND_5', (0, 1))))}
